<?php

/**
 * @file
 * Acuvue ldadmin INC
 */

/**
 * Form callback.
 */
function _ldadmin_form($form, &$form_state) {
  $url_config = variable_get('ldadmin_tags_url_config', array());
  
  $form['ldadmin']['pages'] = array(
    '#type' => 'fieldset',
    '#title' => t('Pages'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#prefix' => '<div id="ldadmin-pages">',
    '#suffix' => '</div>',
    '#tree' => FALSE,
    'add' => array(
      '#type' => 'submit',
      '#value' => t('Add'),
      '#submit' => array('_ldadmin_add_more_add_one'),
      '#validate' => array(),
      '#limit_validation_errors' => array(),
      '#ajax' => array(
        'callback' => '_ldadmin_add_more_callback',
        'wrapper' => 'ldadmin-pages',
      ),
      '#weight' => 100,
    ),
    'ldadmin_tags_url_config' => array(
      '#tree' => TRUE,
    ),
  );

  // First load of the form.
  if (empty($form_state['num_url'])) {
    $form_state['deleted_items'] = array();
    $num_url = 0;

    if (is_array($url_config)) {
      $num_url = count($url_config);
    }

    for ($i = 0; $i < $num_url; $i++) {
      $form['ldadmin']['pages']['ldadmin_tags_url_config'][$i] = _ldadmin_tags_get_fields($url_config[$i], $i);
    }

    if ($num_url == 0) {
      $form['ldadmin']['pages']['ldadmin_tags_url_config'][] = _ldadmin_tags_get_fields(array(), 0);
      $num_url++;
    }
    $form_state['num_url'] = $num_url;
  }
  // Ajax part.
  else {
    $num_url = $form_state['num_url'];
    for ($i = 0; $i < $num_url; $i++) {
      // Only put in the form the remaining items.
      if (!in_array($i, $form_state['deleted_items'])) {
        $form['ldadmin']['pages']['ldadmin_tags_url_config'][$i] = _ldadmin_tags_get_fields(array(), $i);
      }
    }
  }
  
  $form['#submit'][] = '_ldadmin_tags_form_submit';

  return system_settings_form($form);
}

/**
 * Get fields to insert a new specific config object.
 * @param type $values Default values.
 * @param type $id item ID.
 * @return string form fields.
 */
function _ldadmin_tags_get_fields($values, $id = NULL) {

  $fields = array(
    '#type' => 'fieldset',
  );

  if(!isset($values['ldadmin_description']) || 
     !isset($values['ldadmin_tags_path']) || 
     !isset($values['ldadmin_script']) ) {
    $values['ldadmin_description'] = NULL;
    $values['ldadmin_tags_path'] = NULL;
    $values['ldadmin_script'] = NULL;
  }

  $fields['ldadmin_description'] = array(
    '#type' => 'textfield',
    '#title' => t('Description'),
    '#default_value' => $values['ldadmin_description'],
    '#size' => 60,
    '#maxlength' => 100,
    '#required' => TRUE,
  );

  $fields['ldadmin_tags_path'] = array(
      '#type' => 'textfield',
      '#title' => t('Path'),
      '#description' => t('Please put the node ID for input the script. i.e: 398.'),
      '#default_value' => $values['ldadmin_tags_path'],
      '#size' => 60,
      '#required' => TRUE,
  );

  $fields['ldadmin_script'] = array(
    '#type' => 'textarea',
    '#title' => t('Page Selector'),
    '#description' => t('Specify the JSON-LD'),
    '#default_value' => $values['ldadmin_script'],
    '#size' => 60,
    '#required' => FALSE,
  );
  
  $fields['remove-' . $id] = array(
    '#type' => 'submit',
    '#name' => 'remove-' . $id,
    '#delta' => $id,
    '#value' => t('Remove'),
    '#submit' => array('_ldadmin_add_more_remove_one'),
    '#validate' => array(),
    '#limit_validation_errors' => array(),
    '#ajax' => array(
      'callback' => '_ldadmin_add_more_callback',
      'wrapper' => 'ldadmin-pages',
    ),
  );
  
  return $fields;
}

/**
 * Callback for both ajax-enabled buttons.
 *
 * Selects and returns the fieldset with the names in it.
 */
function _ldadmin_add_more_callback($form, $form_state) {
  return $form['ldadmin']['pages'];
}

/**
 * Submit handler for the "add more" button.
 *
 * Increments the max counter and causes a rebuild.
 */
function _ldadmin_add_more_add_one($form, &$form_state) {
  $form_state['num_url'] ++;
  $form_state['rebuild'] = TRUE;
}

/**
 * Submit handler for the "remove" button.
 */
function _ldadmin_add_more_remove_one($form, &$form_state) {
  // Keep the list of deleted items.
  $form_state['deleted_items'][] = $form_state['triggering_element']['#delta'];
  $form_state['rebuild'] = TRUE;
}

/**
 * Form submit.
 */
function _ldadmin_tags_form_submit($form, &$form_state) {
  // Organize the index of the array.
  $form_state['values']['ldadmin_tags_url_config'] = array_values($form_state['values']['ldadmin_tags_url_config']);
}
